@@ -3,8 +3,8 @@ from copy import deepcopy
 
 from pymbse.optim.cache_database_api import get_max_optimization_ix
 from pymbse.optim.config.OptimizationConfig import OptimizationConfig
-from pymbse.optim.design_variable.DesignVariableFactory import init_genetic_design_variables_with_csv
-from pymbse.optim.design_variable.Individual import Individual
+from pymbse.optim.design_variable.DesignVariableFactory import init_design_variables_with_csv
+from pymbse.optim.design_variable.GeneticIndividual import GeneticIndividual
 from pymbse.optim.genetic.update_operators import UpdateOperatorFactory
 
 
@@ -13,7 +13,7 @@ class GeneticOptimizationBuilder:
     @classmethod
     def build(cls, config: OptimizationConfig, ip_with_port_cache: str = ''):
         update_operator = UpdateOperatorFactory.build(config.update_operator_config)
-        design_variables = init_genetic_design_variables_with_csv(config.design_variables_rel_path)
+        design_variables = init_design_variables_with_csv(config.design_variables_rel_path)
         return GeneticOptimization(n_pop=config.n_pop,
                                    n_gen=config.n_gen,
                                    update_operator=update_operator,
@@ -64,7 +64,7 @@ class GeneticOptimization:
     def initialize_or_execute(self, gen):
         if gen == 0:
             while len(self.individuals) < self.n_pop:
-                individual = Individual(self.design_variables)
+                individual = GeneticIndividual(self.design_variables)
                 individual = self.generate_random_individual(individual)
                 individual = self.execute_model(individual, self.optimization_ix, gen, len(self.individuals))
 
@@ -75,21 +75,21 @@ class GeneticOptimization:
                                 for individual_index, individual in enumerate(self.individuals)]
 
     @staticmethod
-    def generate_random_individual(individual: Individual) -> Individual:
+    def generate_random_individual(individual: GeneticIndividual) -> GeneticIndividual:
         individual_copy = deepcopy(individual)
         individual_copy.generate_random_genes()
         return individual_copy
 
     @classmethod
     def execute_model(cls,
-                      individual: Individual,
+                      individual: GeneticIndividual,
                       optimization_ix: int,
                       generation_ix: int,
                       individual_ix: int
-                      ) -> Individual:
+                      ) -> GeneticIndividual:
         individual_out = deepcopy(individual)
         try:
-            artefacts = GeneticOptimization.execute_value_model_with_pymbse(individual,
+            artefacts = GeneticOptimization.execute_value_model_with_pymbse(individual.get_design_variables(),
                                                                             optimization_ix,
                                                                             generation_ix,
                                                                             individual_ix)
@@ -106,8 +106,11 @@ class GeneticOptimization:
         return individual_out
 
     @staticmethod
-    def execute_value_model_with_pymbse(individual, optimization_ix, generation_ix, individual_ix) -> dict:
-        value = sum([gen_dv.value ** 2 for gen_dv in individual.gen_dvs])
+    def execute_value_model_with_pymbse(design_variables: list,
+                                        optimization_ix=None,
+                                        generation_ix=None,
+                                        individual_ix=None) -> dict:
+        value = sum([design_variable['value'] ** 2 for design_variable in design_variables])
         return {'value': value}
 
     def display_scores(self):
